@@ -5,7 +5,7 @@ use warnings;
 
 use 5.008;
 
-our $VERSION = '0.45';
+our $VERSION = '0.47';
 
 1;
 
@@ -23,7 +23,7 @@ Specio - Type constraints and coercions for Perl
 
 =head1 VERSION
 
-version 0.45
+version 0.47
 
 =head1 SYNOPSIS
 
@@ -82,22 +82,22 @@ distribution will magically make the Perl interpreter start checking a value's
 type on assignment to a variable. In fact, there's no built-in way to apply a
 type to a variable at all.
 
-Instead, you can explicitly check a value against a type, and optionally
-coerce values to that type.
+Instead, you can explicitly check a value against a type, and optionally coerce
+values to that type.
 
 My long-term goal is to replace Moose's built-in types and L<MooseX::Types>
 with this module.
 
 =head1 WHAT IS A TYPE?
 
-At it's core, a type is simply a constraint. A constraint is code that checks
-a value and returns true or false. Most constraints are represented by
-L<Specio::Constraint::Simple> objects. However, there are other type
-constraint classes for specialized kinds of constraints.
+At it's core, a type is simply a constraint. A constraint is code that checks a
+value and returns true or false. Most constraints are represented by
+L<Specio::Constraint::Simple> objects. However, there are other type constraint
+classes for specialized kinds of constraints.
 
-Types can be named or anonymous, and each type can have a parent type. A
-type's constraint is optional because sometimes you may want to create a named
-subtype of some existing type without adding additional constraints.
+Types can be named or anonymous, and each type can have a parent type. A type's
+constraint is optional because sometimes you may want to create a named subtype
+of some existing type without adding additional constraints.
 
 Constraints can be expressed either in terms of a simple subroutine reference
 or in terms of an inline generator subroutine reference. The former is easier
@@ -146,9 +146,9 @@ The C<Undef> type only accepts C<undef>.
 
 The C<Defined> type accepts anything I<except> C<undef>.
 
-The C<Num> and C<Int> types are stricter about numbers than Perl
-is. Specifically, they do not allow any sort of space in the number, nor do
-they accept "Nan", "Inf", or "Infinity".
+The C<Num> and C<Int> types are stricter about numbers than Perl is.
+Specifically, they do not allow any sort of space in the number, nor do they
+accept "Nan", "Inf", or "Infinity".
 
 The C<ClassName> type constraint checks that the name is valid I<and> that the
 class is loaded.
@@ -163,8 +163,8 @@ below for details.
 
 Perl's overloading is horribly broken and doesn't make much sense at all.
 
-However, unlike Moose, all type constraints allow overloaded objects where
-they make sense.
+However, unlike Moose, all type constraints allow overloaded objects where they
+make sense.
 
 For types where overloading makes sense, we explicitly check that the object
 provides the type overloading we expect. We I<do not> simply try to use the
@@ -209,8 +209,8 @@ the parameter applies to the values (keys are never checked).
 
 The C<Maybe> type is a special parameterized type. It allows for either
 C<undef> or a value. All by itself, it is meaningless, since it is equivalent
-to "Maybe of Item", which is equivalent to Item. When parameterized, it
-accepts either an C<undef> or the type of its parameter.
+to "Maybe of Item", which is equivalent to Item. When parameterized, it accepts
+either an C<undef> or the type of its parameter.
 
 This is useful for optional attributes or parameters. However, you're probably
 better off making your code simply not pass the parameter at all This usually
@@ -231,8 +231,8 @@ not exposed to your code. To access a type, you always call C<t('TypeName')>.
 
 This returns the named type or dies if no such type exists.
 
-Because types are always copied on import, it's safe to create coercions on
-any type. Your coercion from C<Str> to C<Int> will not be seen by any other
+Because types are always copied on import, it's safe to create coercions on any
+type. Your coercion from C<Str> to C<Int> will not be seen by any other
 package, unless that package explicitly imports your C<Int> type.
 
 When you import types, you import every type defined in the package you import
@@ -241,8 +241,8 @@ definition. You I<cannot> define the same type twice internally.
 
 =head1 CREATING A TYPE LIBRARY
 
-By default, all types created inside a package are invisible to other
-packages. If you want to create a type library, you need to inherit from
+By default, all types created inside a package are invisible to other packages.
+If you want to create a type library, you need to inherit from
 L<Specio::Exporter> package:
 
   package MyApp::Type::Library;
@@ -258,9 +258,8 @@ L<Specio::Exporter> package:
       where  => sub { $_[0] =~ /foo/i },
   );
 
-Now the MyApp::Type::Library package will export a single type named
-C<Foo>. It I<does not> re-export the types provided by
-L<Specio::Library::Builtins>.
+Now the MyApp::Type::Library package will export a single type named C<Foo>. It
+I<does not> re-export the types provided by L<Specio::Library::Builtins>.
 
 If you want to make your library re-export some other libraries types, you can
 ask for this explicitly:
@@ -289,9 +288,9 @@ This should just work. Use a Specio type anywhere you'd specify a type.
 
 =head1 USING SPECIO WITH L<Moo>
 
-Using Specio with Moo is easy. You can pass Specio constraint objects as
-C<isa> parameters for attributes. For coercions, simply call C<<
-$type->coercion_sub >>.
+Using Specio with Moo is easy. You can pass Specio constraint objects as C<isa>
+parameters for attributes. For coercions, simply call C<< $type->coercion_sub
+>>.
 
     package Foo;
 
@@ -359,18 +358,18 @@ MooseX::Types, which assume that unknown names are class names.
 =item * Anon types are explicit
 
 With L<Moose> and L<MooseX::Types>, you use the same subroutine, C<subtype()>,
-to declare both named and anonymous types. With Specio, you use C<declare()> for
-named types and C<anon()> for anonymous types.
+to declare both named and anonymous types. With Specio, you use C<declare()>
+for named types and C<anon()> for anonymous types.
 
 =item * Class and object types are separate
 
 Moose and MooseX::Types have C<class_type> and C<duck_type>. The former type
 requires an object, while the latter accepts a class name or object.
 
-With Specio, the distinction between accepting an object versus object or
-class is explicit. There are six declaration helpers, C<object_can_type>,
-C<object_does_type>, C<object_isa_type>, C<any_can_type>, C<any_does_type>,
-and C<any_isa_type>.
+With Specio, the distinction between accepting an object versus object or class
+is explicit. There are six declaration helpers, C<object_can_type>,
+C<object_does_type>, C<object_isa_type>, C<any_can_type>, C<any_does_type>, and
+C<any_isa_type>.
 
 =item * Overloading support is baked in
 
@@ -379,8 +378,8 @@ frustrating to use in many cases.
 
 =item * Types can either have a constraint or inline generator, not both
 
-Moose and MooseX::Types types can be defined with a subroutine reference as
-the constraint, an inline generator subroutine, or both. This is purely for
+Moose and MooseX::Types types can be defined with a subroutine reference as the
+constraint, an inline generator subroutine, or both. This is purely for
 backwards compatibility, and it makes the internals more complicated than they
 need to be.
 
@@ -393,8 +392,8 @@ I simply never got around to implementing this in Moose.
 
 =item * No crazy coercion features
 
-Moose has some bizarre (and mostly) undocumented features relating to
-coercions and parameterizable types. This is a misfeature.
+Moose has some bizarre (and mostly) undocumented features relating to coercions
+and parameterizable types. This is a misfeature.
 
 =back
 
@@ -459,7 +458,7 @@ software much more, unless I get so many donations that I can consider working
 on free software full time (let's all have a chuckle at that together).
 
 To donate, log into PayPal and send money to autarch@urth.org, or use the
-button at L<http://www.urth.org/~autarch/fs-donation.html>.
+button at L<https://www.urth.org/fs-donation.html>.
 
 =head1 AUTHOR
 
@@ -491,7 +490,7 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2019 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2021 by Dave Rolsky.
 
 This is free software, licensed under:
 
